==> 0.1.0.tar.gz: lib/nearby_ui_option.dart <==
part of mapmyindia_nearby_plugin;

class NearbyUIOption {
  final String? backgroundColor;
  final String? refLocationCircleColor;
  final double? circleAlpha;
  final String? paginationContainerViewBackgroundColor;
  final Uint8List? paginationPreviousButtonImage;
  final String? paginationPreviousButtonbackgroundcolor;
  final Uint8List? paginationNextButtonImage;
  final String? paginationNextButtonbackgroundcolor;
  final String? nearbyFilterViewContainerBackgroundColor;
  final double? nearbyFilterCellBorderWidth;
  final String? nearbyFilterCellBorderColor;
  final double? nearbyFilterCellCornerRadius;
  final String? nearbySegmentedViewContainerBackgroundColor;
  final int? segmentedControlSelectedSegmentIndex;
  final String? segmentedControlBackgroundColor;
  final String? segmentedControlBorderColor;
  final double? segmentedControlBorderWidth;
  final String? segmentedControlSelectedSegmentTintColor;
  final String? segmentedControlUnselectedforegroundColor;
  final String? segmentedControlSelectedforegroundColor;
  final String? segmentedControltTextFont;
  final String? tableCellBackgroundColor;
  final String? tableCellSeparatorColor;
  final String? placeNameTextColor;
  final String? placeAddressTextColor;
  final String? distanceTextColor;
  final String? navigationBackgroundColor;
  final String? navigationTitleColor;
  final Uint8List? backButtonImage;
  final Uint8List? refLocationIcon;

  final String? nearbyToolbarColor; // done
  final String? nearbyToolbarTintColor; // done
  final String? categoryBackgroundColor; // done
  final String? categoryTextColor; // done
  final String? categoryIconColor;
  final String? changeLocationButtonTextColor; // done
  final String? locationDetailFormattedAddressTextColor; // done
  final String? locationDetailInfoTextColor; // done
  final String? locationDetailsBackgroundColor; // done
  final String? locationDetailsInfoLabelText; // done
  final Uint8List? nearbyToolbarIcon; // done
  final String? selectedCategoryBackgroundColor; // done
  final String? selectedCategoryTextColor; // done
  final String? selectedCategoryIconColor; // done
  final String? submitButtonColor; // done
  final String? submitButtonText; // done
  final String? useCurrentLocationButtonTextColor; //done
  final String? submitButtonTextColor; //done

// nearbyPresentStyle

  NearbyUIOption(
      {this.paginationPreviousButtonImage,
      this.paginationNextButtonImage,
      this.backButtonImage,
      this.backgroundColor,
      this.refLocationCircleColor,
      this.circleAlpha,
      this.paginationContainerViewBackgroundColor,
      this.paginationPreviousButtonbackgroundcolor,
      this.paginationNextButtonbackgroundcolor,
      this.nearbyFilterViewContainerBackgroundColor,
      this.nearbyFilterCellBorderWidth,
      this.nearbyFilterCellBorderColor,
      this.nearbyFilterCellCornerRadius,
      this.nearbySegmentedViewContainerBackgroundColor,
      this.segmentedControlSelectedSegmentIndex,
      this.segmentedControlBackgroundColor,
      this.segmentedControlBorderColor,
      this.segmentedControlBorderWidth,
      this.segmentedControlSelectedSegmentTintColor,
      this.segmentedControlUnselectedforegroundColor,
      this.segmentedControlSelectedforegroundColor,
      this.segmentedControltTextFont,
      this.tableCellBackgroundColor,
      this.tableCellSeparatorColor,
      this.placeNameTextColor,
      this.placeAddressTextColor,
      this.distanceTextColor,
      this.navigationBackgroundColor,
      this.refLocationIcon,
      this.navigationTitleColor,
      this.nearbyToolbarColor,
      this.nearbyToolbarTintColor,
      this.categoryBackgroundColor,
      this.categoryTextColor,
      this.categoryIconColor,
      this.changeLocationButtonTextColor,
      this.locationDetailFormattedAddressTextColor,
      this.locationDetailInfoTextColor,
      this.locationDetailsBackgroundColor,
      this.locationDetailsInfoLabelText,
      this.nearbyToolbarIcon,
      this.selectedCategoryBackgroundColor,
      this.selectedCategoryTextColor,
      this.selectedCategoryIconColor,
      this.submitButtonColor,
      this.submitButtonText,
      this.useCurrentLocationButtonTextColor,
      this.submitButtonTextColor});

  Map<String, dynamic> toMap() {
    final Map<String, dynamic> optionsMap = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        optionsMap[fieldName] = value;
      }
    }

    void addMapIfNonNull(String fieldName, Uint8List value) {
      if (value != null) {
        optionsMap[fieldName] = <String, dynamic>{
          'image': value,
          'length': value.length
        };
      }
    }

    addIfNonNull('backgroundColor', backgroundColor);
    addIfNonNull('refLocationCircleColor', refLocationCircleColor);
    addIfNonNull('circleAlpha', circleAlpha);
    addIfNonNull('paginationContainerViewBackgroundColor',
        paginationContainerViewBackgroundColor);

    //Only IOS
    if (paginationPreviousButtonImage != null) {
      addMapIfNonNull(
          'paginationPreviousButtonImage', paginationPreviousButtonImage!);
    }
//Only IOS
    if (paginationNextButtonImage != null) {
      addMapIfNonNull('paginationNextButtonImage', paginationNextButtonImage!);
    }
//Only IOS
    if (backButtonImage != null) {
      addMapIfNonNull('backButtonImage', backButtonImage!);
    }
    //Only IOS
    addIfNonNull('paginationNextButtonImage', paginationNextButtonImage);
    addIfNonNull('paginationPreviousButtonbackgroundcolor',
        paginationPreviousButtonbackgroundcolor);
    addIfNonNull('paginationNextButtonbackgroundcolor',
        paginationNextButtonbackgroundcolor);
    addIfNonNull('nearbyFilterViewContainerBackgroundColor',
        nearbyFilterViewContainerBackgroundColor);
    //Only IOS
    addIfNonNull('nearbyFilterCellBorderWidth', nearbyFilterCellBorderWidth);
    //Only IOS
    addIfNonNull('nearbySegmentedViewContainerBackgroundColor',
        nearbySegmentedViewContainerBackgroundColor);
    //Only IOS
    addIfNonNull('segmentedControlSelectedSegmentIndex',
        segmentedControlSelectedSegmentIndex);
    addIfNonNull(
        'segmentedControlBackgroundColor', segmentedControlBackgroundColor);
    //Only IOS
    addIfNonNull('segmentedControlBorderColor', segmentedControlBorderColor);
    //Only IOS
    addIfNonNull('segmentedControlBorderWidth', segmentedControlBorderWidth);
    addIfNonNull('segmentedControlSelectedSegmentTintColor',
        segmentedControlSelectedSegmentTintColor);
    //Only IOS
    addIfNonNull('segmentedControltTextFont', segmentedControltTextFont);
    addIfNonNull('tableCellBackgroundColor', tableCellBackgroundColor);
    addIfNonNull('tableCellSeparatorColor', tableCellSeparatorColor);

    addIfNonNull('placeNameTextColor', placeNameTextColor);
    addIfNonNull('placeAddressTextColor', placeAddressTextColor);
    addIfNonNull('distanceTextColor', distanceTextColor);
    addIfNonNull('navigationBackgroundColor', navigationBackgroundColor);
    //Only IOS
    addIfNonNull('nearbyFilterCellCornerRadius', nearbyFilterCellCornerRadius);
    addIfNonNull('segmentedControlUnselectedforegroundColor',
        segmentedControlUnselectedforegroundColor);
    //Only IOS
    addIfNonNull('segmentedControlSelectedforegroundColor',
        segmentedControlSelectedforegroundColor);
    //Only IOS
    addIfNonNull('backButtonImage', backButtonImage);

    //New Added Props
    addIfNonNull('refLocationIcon', refLocationIcon);
    addIfNonNull('navigationTitleColor', navigationTitleColor);
    addIfNonNull('nearbyToolbarColor', nearbyToolbarColor);
    addIfNonNull('nearbyToolbarTintColor', nearbyToolbarTintColor);
    addIfNonNull('categoryBackgroundColor', categoryBackgroundColor);
    addIfNonNull('categoryTextColor', categoryTextColor);
    addIfNonNull('categoryIconColor', categoryIconColor);
    addIfNonNull('changeLocationButtonTextColor', changeLocationButtonTextColor);
    addIfNonNull('locationDetailFormattedAddressTextColor', locationDetailFormattedAddressTextColor);
    addIfNonNull('locationDetailInfoTextColor', locationDetailInfoTextColor);
    addIfNonNull('locationDetailsBackgroundColor', locationDetailsBackgroundColor);
    addIfNonNull('locationDetailsInfoLabelText', locationDetailsInfoLabelText);
    addIfNonNull('nearbyToolbarIcon', nearbyToolbarIcon);
    addIfNonNull('selectedCategoryBackgroundColor', selectedCategoryBackgroundColor);
    addIfNonNull('selectedCategoryTextColor', selectedCategoryTextColor);
    addIfNonNull('selectedCategoryIconColor', selectedCategoryIconColor);
    addIfNonNull('submitButtonColor', submitButtonColor);
    addIfNonNull('submitButtonText', submitButtonText);
    addIfNonNull('useCurrentLocationButtonTextColor', useCurrentLocationButtonTextColor);
    addIfNonNull('submitButtonTextColor', submitButtonTextColor);
    return optionsMap;
  }
}

==> 0.2.0.tar.gz: lib/nearby_ui_option.dart <==
part of mapmyindia_nearby_plugin;

/// Used for UI related settings
class NearbyUIOption {
  /// To set the background color of nearby category selection screen
  final String? backgroundColor;

  /// To set circle color around reference location
  final String? refLocationCircleColor;

  /// To set circle alpha for reference location
  final double? circleAlpha;

  /// To set background color of page selection view
  final String? paginationContainerViewBackgroundColor;

  /// To set previous page selector button icon
  final Uint8List? paginationPreviousButtonImage;

  /// To set previous page selector button background
  final String? paginationPreviousButtonbackgroundcolor;

  /// To set next page selector button icon
  final Uint8List? paginationNextButtonImage;

  /// To set next page selector button background
  final String? paginationNextButtonbackgroundcolor;

  /// To set Category Filter Background color
  final String? nearbyFilterViewContainerBackgroundColor;

  final double? nearbyFilterCellBorderWidth;
  final String? nearbyFilterCellBorderColor;
  final double? nearbyFilterCellCornerRadius;
  final String? nearbySegmentedViewContainerBackgroundColor;
  final int? segmentedControlSelectedSegmentIndex;
  final String? segmentedControlBackgroundColor;
  final String? segmentedControlBorderColor;
  final double? segmentedControlBorderWidth;
  final String? segmentedControlSelectedSegmentTintColor;
  final String? segmentedControlUnselectedforegroundColor;
  final String? segmentedControlSelectedforegroundColor;
  final String? segmentedControltTextFont;
  final String? tableCellBackgroundColor;
  final String? tableCellSeparatorColor;

  /// To set result item place name text color
  final String? placeNameTextColor;

  /// To set result item address text color
  final String? placeAddressTextColor;

  /// To set result item distance text color
  final String? distanceTextColor;
  final String? navigationBackgroundColor;
  final String? navigationTitleColor;

  final Uint8List? backButtonImage;

  ///  To set reference location marker icon
  final Uint8List? refLocationIcon;

  /// To set the toolbar color of nearby result screen
  final String? nearbyToolbarColor;
  final String? nearbyToolbarTintColor;

  /// To set category item background color
  final String? categoryBackgroundColor;

  /// To set Category item text color
  final String? categoryTextColor;

  /// To set Category icon color
  final String? categoryIconColor;

  /// To set change location button Text color
  final String? changeLocationButtonTextColor;

  /// To set selected location Address text color
  final String? locationDetailFormattedAddressTextColor;

  /// To set location detail information text color
  final String? locationDetailInfoTextColor;

  /// To set background color of location detail view
  final String? locationDetailsBackgroundColor;

  /// To set location detail information text
  final String? locationDetailsInfoLabelText;

  /// To set the toolbar icon on category selection screen
  final Uint8List? nearbyToolbarIcon;

  /// To set selected category item background color
  final String? selectedCategoryBackgroundColor;

  /// To set selected category item text color
  final String? selectedCategoryTextColor;
  final String? selectedCategoryIconColor; // done
  final String? submitButtonColor; // done
  final String? submitButtonText; // done
  final String? useCurrentLocationButtonTextColor; //done
  final String? submitButtonTextColor; //done

  NearbyUIOption(
      {this.paginationPreviousButtonImage,
      this.paginationNextButtonImage,
      this.backButtonImage,
      this.backgroundColor,
      this.refLocationCircleColor,
      this.circleAlpha,
      this.paginationContainerViewBackgroundColor,
      this.paginationPreviousButtonbackgroundcolor,
      this.paginationNextButtonbackgroundcolor,
      this.nearbyFilterViewContainerBackgroundColor,
      this.nearbyFilterCellBorderWidth,
      this.nearbyFilterCellBorderColor,
      this.nearbyFilterCellCornerRadius,
      this.nearbySegmentedViewContainerBackgroundColor,
      this.segmentedControlSelectedSegmentIndex,
      this.segmentedControlBackgroundColor,
      this.segmentedControlBorderColor,
      this.segmentedControlBorderWidth,
      this.segmentedControlSelectedSegmentTintColor,
      this.segmentedControlUnselectedforegroundColor,
      this.segmentedControlSelectedforegroundColor,
      this.segmentedControltTextFont,
      this.tableCellBackgroundColor,
      this.tableCellSeparatorColor,
      this.placeNameTextColor,
      this.placeAddressTextColor,
      this.distanceTextColor,
      this.navigationBackgroundColor,
      this.refLocationIcon,
      this.navigationTitleColor,
      this.nearbyToolbarColor,
      this.nearbyToolbarTintColor,
      this.categoryBackgroundColor,
      this.categoryTextColor,
      this.categoryIconColor,
      this.changeLocationButtonTextColor,
      this.locationDetailFormattedAddressTextColor,
      this.locationDetailInfoTextColor,
      this.locationDetailsBackgroundColor,
      this.locationDetailsInfoLabelText,
      this.nearbyToolbarIcon,
      this.selectedCategoryBackgroundColor,
      this.selectedCategoryTextColor,
      this.selectedCategoryIconColor,
      this.submitButtonColor,
      this.submitButtonText,
      this.useCurrentLocationButtonTextColor,
      this.submitButtonTextColor});

  Map<String, dynamic> toMap() {
    final Map<String, dynamic> optionsMap = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        optionsMap[fieldName] = value;
      }
    }

    void addMapIfNonNull(String fieldName, Uint8List value) {
      if (value != null) {
        optionsMap[fieldName] = <String, dynamic>{
          'image': value,
          'length': value.length
        };
      }
    }

    addIfNonNull('backgroundColor', backgroundColor);
    addIfNonNull('refLocationCircleColor', refLocationCircleColor);
    addIfNonNull('circleAlpha', circleAlpha);
    addIfNonNull('paginationContainerViewBackgroundColor',
        paginationContainerViewBackgroundColor);

    //Only IOS
    if (paginationPreviousButtonImage != null) {
      addMapIfNonNull(
          'paginationPreviousButtonImage', paginationPreviousButtonImage!);
    }
//Only IOS
    if (paginationNextButtonImage != null) {
      addMapIfNonNull('paginationNextButtonImage', paginationNextButtonImage!);
    }
//Only IOS
    if (backButtonImage != null) {
      addMapIfNonNull('backButtonImage', backButtonImage!);
    }
    //Only IOS
    addIfNonNull('paginationNextButtonImage', paginationNextButtonImage);
    addIfNonNull('paginationPreviousButtonbackgroundcolor',
        paginationPreviousButtonbackgroundcolor);
    addIfNonNull('paginationNextButtonbackgroundcolor',
        paginationNextButtonbackgroundcolor);
    addIfNonNull('nearbyFilterViewContainerBackgroundColor',
        nearbyFilterViewContainerBackgroundColor);
    //Only IOS
    addIfNonNull('nearbyFilterCellBorderWidth', nearbyFilterCellBorderWidth);
    //Only IOS
    addIfNonNull('nearbySegmentedViewContainerBackgroundColor',
        nearbySegmentedViewContainerBackgroundColor);
    //Only IOS
    addIfNonNull('segmentedControlSelectedSegmentIndex',
        segmentedControlSelectedSegmentIndex);
    addIfNonNull(
        'segmentedControlBackgroundColor', segmentedControlBackgroundColor);
    //Only IOS
    addIfNonNull('segmentedControlBorderColor', segmentedControlBorderColor);
    //Only IOS
    addIfNonNull('segmentedControlBorderWidth', segmentedControlBorderWidth);
    addIfNonNull('segmentedControlSelectedSegmentTintColor',
        segmentedControlSelectedSegmentTintColor);
    //Only IOS
    addIfNonNull('segmentedControltTextFont', segmentedControltTextFont);
    addIfNonNull('tableCellBackgroundColor', tableCellBackgroundColor);
    addIfNonNull('tableCellSeparatorColor', tableCellSeparatorColor);

    addIfNonNull('placeNameTextColor', placeNameTextColor);
    addIfNonNull('placeAddressTextColor', placeAddressTextColor);
    addIfNonNull('distanceTextColor', distanceTextColor);
    addIfNonNull('navigationBackgroundColor', navigationBackgroundColor);
    //Only IOS
    addIfNonNull('nearbyFilterCellCornerRadius', nearbyFilterCellCornerRadius);
    addIfNonNull('segmentedControlUnselectedforegroundColor',
        segmentedControlUnselectedforegroundColor);
    //Only IOS
    addIfNonNull('segmentedControlSelectedforegroundColor',
        segmentedControlSelectedforegroundColor);
    //Only IOS
    addIfNonNull('backButtonImage', backButtonImage);

    //New Added Props
    addIfNonNull('refLocationIcon', refLocationIcon);
    addIfNonNull('navigationTitleColor', navigationTitleColor);
    addIfNonNull('nearbyToolbarColor', nearbyToolbarColor);
    addIfNonNull('nearbyToolbarTintColor', nearbyToolbarTintColor);
    addIfNonNull('categoryBackgroundColor', categoryBackgroundColor);
    addIfNonNull('categoryTextColor', categoryTextColor);
    addIfNonNull('categoryIconColor', categoryIconColor);
    addIfNonNull(
        'changeLocationButtonTextColor', changeLocationButtonTextColor);
    addIfNonNull('locationDetailFormattedAddressTextColor',
        locationDetailFormattedAddressTextColor);
    addIfNonNull('locationDetailInfoTextColor', locationDetailInfoTextColor);
    addIfNonNull(
        'locationDetailsBackgroundColor', locationDetailsBackgroundColor);
    addIfNonNull('locationDetailsInfoLabelText', locationDetailsInfoLabelText);
    addIfNonNull('nearbyToolbarIcon', nearbyToolbarIcon);
    addIfNonNull(
        'selectedCategoryBackgroundColor', selectedCategoryBackgroundColor);
    addIfNonNull('selectedCategoryTextColor', selectedCategoryTextColor);
    addIfNonNull('selectedCategoryIconColor', selectedCategoryIconColor);
    addIfNonNull('submitButtonColor', submitButtonColor);
    addIfNonNull('submitButtonText', submitButtonText);
    addIfNonNull(
        'useCurrentLocationButtonTextColor', useCurrentLocationButtonTextColor);
    addIfNonNull('submitButtonTextColor', submitButtonTextColor);
    return optionsMap;
  }
}
